@@ -3,12 +3,13 @@
 # Description: This file contains model loading functions
 
 def load_config(file_path='config.json'):
+    import json
     with open(file_path, "r") as f:
         config = json.load(f)
     return config
 
 def load_model(model_name):
-    config = load_config()
-    model_path = config['model_path']
-    model = load_model(model_path + model_name)
-    return model
\ No newline at end of file
+    from transformers import AutoTokenizer, AutoModelForTokenClassification
+    tokenizer = AutoTokenizer.from_pretrained(model_name)
+    model = AutoModelForTokenClassification.from_pretrained(model_name)
+    return tokenizer, model
\ No newline at end of file
