@@ -1,6 +1,6 @@
 from aimped.nlp import assertion
-from aimped.nlp import chunk_merger
-from aimped.nlp import cleaner
+from aimped.nlp import chunker
+from aimped.nlp import tools
 from aimped.nlp import deid
 from aimped.nlp import ner
 from aimped.nlp import regex_parser
